# importation des bibliothèques de calcul et de tracé
import matplotlib.pyplot as plt
import numpy as np
from random import randint
from matplotlib.widgets import Button


# =================================================================
# Choix aléatoire d'une charge et d'un rayon pour la goutte d'huile
# =================================================================
n= randint(1,9)     # choix alétaoire d'un entier compris entre 1 et 9
e = 1.6e-19         # charge électrique élémentaire (C)
q = -n*e            # charge électrique de la goutte
n2 = randint (-9,9) # choix alétaoire d'un entier compris entre -9 et 9
r = 1e-6+n2*1e-7    # rayon de la goutte (en m)


# ==========================================================
# valeurs numériques des différentes données de l'expérience
# ==========================================================
eta = 1.81e-5                       # viscosité de l'air (en kg.m-1.s-1)
rho = 850                           # masse volumique de l'huile (en kg.m-3)
g = 9.81                            # intensité du champ de pesanteur terrestre (m.s-2)
V = (4 * np.pi * r**3)/3            # volume de la goutte (m3)
m = V * rho                         # masse de la goutte (kg)
E = 35000                           # valeur du champ électrostatique

""" _________________________________________
    Lignes 30 à 32 à compléter par les élèves """
# saisir ici l'expression du temps caractéristique : variable "tau"
# saisir ici l'expression de la vitesse limite avec champ E vers le bas : variable "vlim1"
# saisir ici l'expression de la vitesse limite avec champ E vers le haut : variable "vlim2"

# ==================================================
# Création d'une liste de dates à porter en abscisse
# ==================================================
tmax = 10*tau
t = np.arange(0, tmax, tmax/200)    # crée une liste de 200 valeurs de dates

# =============================================================================
# Vitesse de chute avec un champ vers le bas (v1) et un champ vers le haut (v2)
# =============================================================================
v1 = vlim1 * (1-np.exp(-t/tau))
v2 = vlim2 * (1-np.exp(-t/tau))

# =================
# tracé des courbes
# =================
fig=plt.figure()
fig.patch.set_facecolor('#E0E0E0')

graphe = fig.add_subplot(111)                               # On travaille dans la zone graphique du haut
graphe.patch.set_facecolor('#525354')                       # Couleur du fond


plt.plot (t,v1,'-',color='gold', label='champ électrostatique de 35kV vers le bas')
plt.plot (t,v2,'-',color='hotpink', label='champ champ électrostatique de 35kV vers le haut')

plt.xlabel('temps (s)')
plt.ylabel('vitesse (m.s-1)')
plt.legend(loc='best')
plt.subplots_adjust(bottom=0.3)
plt.grid()                                                  # Ajoute un quadrillage


# =================================================
# Affichage de r et q quand on clique sur le bouton
# =================================================
bax1 = plt.axes([0.25, 0.18, 0.65, 0.04]) 
bouton = Button(bax1, 'Voir les valeurs de la charge et du rayon', color='steelblue', hovercolor='lightsteelblue')

def Affiche_valeurs(event): 
    valeurs = 'Charge électrique de la goutte : q = '+str(n)+'e = '+str("%.2E"%q)+' C \nRayon de la goutte : r = '+str("%.2E"%r)+' m'
    plt.figtext(0.25, 0.05, valeurs, fontsize = 14)
    plt.show()


bouton.on_clicked(Affiche_valeurs)

plt.get_current_fig_manager().window.state('zoomed')   # pour que les graphiques s'affichent en plein écran
plt.show()

